@@ -2,38 +2,15 @@
 
 import json
 import logging
-from functools import wraps
 from http import HTTPStatus
 
+import requests
 from oauth2_xfel_client.oauth2_client_backend import Oauth2ClientBackend
-from oauthlib.oauth2 import TokenExpiredError
 
 from ..common.config import CREATE, DELETE, UPDATE, GET, SET, \
     DEF_MAX_RETRIES, DEF_TIMEOUT, DEF_SSL_VERIFY
 
 
-def replace_expired_token(func):
-    """Decorator to catch TokenExpiredError and make a session with a new token
-
-    Doing it this way avoids a race condition where a token can expire between
-    checking and using it. It also hopefully copes better if the client and
-    server clocks are not precisely synchronised.
-
-    TODO: Auto-refresh should be handled in requests_oauthlib, but
-    oauth2_xfel_client v5.1.1 doesn't seem to use this.
-    """
-
-    @wraps(func)
-    def inner(self, *args, **kwargs):
-        try:
-            return func(self, *args, **kwargs)
-        except TokenExpiredError:
-            self.oauth_client.auth_session()  # Get a new session token
-            return func(self, *args, **kwargs)
-
-    return inner
-
-
 def default_headers(user_email):
     return {
         'content-type': 'application/json',
@@ -43,24 +20,36 @@ def default_headers(user_email):
 
 
 class Base:
-    def __init__(self,
-                 client_id, client_secret,
-                 token_url, refresh_url, auth_url, scope,
-                 user_email, base_api_url,
+    def __init__(self, *,
+                 base_api_url, use_oauth2=True,
+                 client_id='', client_secret='',
+                 token_url='', refresh_url='', auth_url='', scope='',
+                 user_email='',
                  session_token=None,
                  max_retries=DEF_MAX_RETRIES,
                  timeout=DEF_TIMEOUT,
                  ssl_verify=DEF_SSL_VERIFY):
-        self.oauth_client = Oauth2ClientBackend(client_id=client_id,
-                                                client_secret=client_secret,
-                                                scope=scope,
-                                                token_url=token_url,
-                                                refresh_url=refresh_url,
-                                                auth_url=auth_url,
-                                                session_token=session_token,
-                                                max_retries=max_retries,
-                                                timeout=timeout,
-                                                ssl_verify=ssl_verify)
+
+        if use_oauth2:
+            self.oauth_client = Oauth2ClientBackend(
+                client_id=client_id,
+                client_secret=client_secret,
+                scope=scope,
+                token_url=token_url,
+                refresh_url=refresh_url,
+                auth_url=auth_url,
+                session_token=session_token,
+                max_retries=max_retries,
+                timeout=timeout,
+                ssl_verify=ssl_verify
+            )
+            self.session = self.oauth_client.session
+
+        else:
+            # Oauth disabled - used with base_api_url pointing to an
+            # xfel-oauth-proxy instance
+            self.oauth_client = None
+            self.session = requests.Session()
 
         self.headers = default_headers(user_email)
         # Ensure the base URL has a trailing slash
@@ -186,7 +175,6 @@ class Base:
         complete_api_specifics = '{0}{1}'.format(model_name, api_specifics)
         return '{0}{1}'.format(self.base_api_url, complete_api_specifics)
 
-    @replace_expired_token
     def api_get(self, api_url, **kwargs):
         """Sends a GET request. Returns :class:`Response` object.
         :param api_url: URL for the new :class:`Request` object.
@@ -194,11 +182,8 @@ class Base:
         """
         kwargs.setdefault('allow_redirects', True)
 
-        return self.oauth_client.session.get(api_url,
-                                             headers=self.headers,
-                                             **kwargs)
+        return self.session.get(api_url, headers=self.headers, **kwargs)
 
-    @replace_expired_token
     def api_post(self, api_url, **kwargs):
         """Sends a POST request. Returns :class:`Response` object.
         :param api_url: URL for the new :class:`Request` object.
@@ -206,11 +191,8 @@ class Base:
         """
         kwargs.setdefault('allow_redirects', True)
 
-        return self.oauth_client.session.post(api_url,
-                                              headers=self.headers,
-                                              **kwargs)
+        return self.session.post(api_url, headers=self.headers, **kwargs)
 
-    @replace_expired_token
     def api_put(self, api_url, **kwargs):
         """Sends a PUT request. Returns :class:`Response` object.
         :param api_url: URL for the new :class:`Request` object.
@@ -218,11 +200,8 @@ class Base:
         """
         kwargs.setdefault('allow_redirects', True)
 
-        return self.oauth_client.session.put(api_url,
-                                             headers=self.headers,
-                                             **kwargs)
+        return self.session.put(api_url, headers=self.headers, **kwargs)
 
-    @replace_expired_token
     def api_delete(self, api_url, **kwargs):
         """Sends a DELETE request. Returns :class:`Response` object.
         :param api_url: URL for the new :class:`Request` object.
@@ -230,6 +209,4 @@ class Base:
         """
         kwargs.setdefault('allow_redirects', True)
 
-        return self.oauth_client.session.delete(api_url,
-                                                headers=self.headers,
-                                                **kwargs)
+        return self.session.delete(api_url, headers=self.headers, **kwargs)
