@@ -86,7 +86,7 @@ class CalibrationApiTest(ApiBase, unittest.TestCase):
         unique_name = generate_unique_name('CalibrationApiUpd')
         calibration_upd = {
             'calibration': {
-                'name': unique_name,
+                'name': expect['name'],
                 # 'unit_id': '-1',
                 'max_value': 12.0,
                 'min_value': 3.0,
@@ -106,7 +106,6 @@ class CalibrationApiTest(ApiBase, unittest.TestCase):
         self.fields_validation(receive, expect_upd)
         assert resp.status_code == HTTPStatus.OK
 
-        assert expect['name'] != expect_upd['name']
         assert expect['max_value'] != expect_upd['max_value']
         assert expect['min_value'] != expect_upd['min_value']
         assert expect['allowed_deviation'] != expect_upd['allowed_deviation']
