@@ -472,20 +472,22 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         # sort results
         data_sorted = sorted(results['data'], key=lambda d: -d['id'])
 
-        assert [(d['id'], d['name'], d['physical_detector_unit']['physical_name']) for d in data_sorted] == [  # noqa
-            (-7, 'CALIBRATION_CONSTANT_VERSION_TEST-7_DO_NOT_DELETE',
-             'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE'),
-            (-8, 'CALIBRATION_CONSTANT_VERSION_TEST-8_DO_NOT_DELETE',
-             'PHYSICAL_DETECTOR_UNIT-2_DO_NOT_DELETE'),
-            (-9, 'CALIBRATION_CONSTANT_VERSION_TEST-9_DO_NOT_DELETE',
-             'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE'),
-            (-10, 'CALIBRATION_CONSTANT_VERSION_TEST-10_DO_NOT_DELETE',
-             'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE'),
-            (-11, 'CALIBRATION_CONSTANT_VERSION_TEST-11_DO_NOT_DELETE',
-             'PHYSICAL_DETECTOR_UNIT-2_DO_NOT_DELETE'),
-            (-12, 'CALIBRATION_CONSTANT_VERSION_TEST-12_DO_NOT_DELETE',
-             'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE')
-        ]
+        assert [(d['id'], d['name'],
+                 d['physical_detector_unit']['physical_name']) for d in
+                data_sorted] == [
+                   (-7, 'CALIBRATION_CONSTANT_VERSION_TEST-7_DO_NOT_DELETE',
+                    'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE'),
+                   (-8, 'CALIBRATION_CONSTANT_VERSION_TEST-8_DO_NOT_DELETE',
+                    'PHYSICAL_DETECTOR_UNIT-2_DO_NOT_DELETE'),
+                   (-9, 'CALIBRATION_CONSTANT_VERSION_TEST-9_DO_NOT_DELETE',
+                    'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE'),
+                   (-10, 'CALIBRATION_CONSTANT_VERSION_TEST-10_DO_NOT_DELETE',
+                    'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE'),
+                   (-11, 'CALIBRATION_CONSTANT_VERSION_TEST-11_DO_NOT_DELETE',
+                    'PHYSICAL_DETECTOR_UNIT-2_DO_NOT_DELETE'),
+                   (-12, 'CALIBRATION_CONSTANT_VERSION_TEST-12_DO_NOT_DELETE',
+                    'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE')
+               ]
 
     #
     # fields_validation
